.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.pager
----------------------

.. automodule:: reahl.web.pager

PageMenu
""""""""

.. autoclass:: PageMenu
   :members:
   

PagedPanel
""""""""""

.. autoclass:: PagedPanel
   :members:


PageIndex
"""""""""

.. autoclass:: PageIndex
   :members:

SequentialPageIndex
"""""""""""""""""""

.. autoclass:: SequentialPageIndex
   :members:

AnnualPageIndex
"""""""""""""""

.. autoclass:: AnnualPageIndex
   :members:
   
AnnualItemOrganiserProtocol
"""""""""""""""""""""""""""

.. autoclass:: AnnualItemOrganiserProtocol
   :members:   

